

*****
MLTSA
*****

Info
#####

This is a Python module to apply the MLTSA approach for relevant CV identification on Molecular Dynamics data using both Sklearn and TensorFlow modules.

> examples : Contains files with the easy to call 1D/2D/MD examples to generate data or play around with it as tests for the approach.

> MLTSA_sklearn : Contains the Scikit-Learn integrated functions to apply MLTSA on data.

> MLTSA_tensorflow: Contains the set of functions and different models built on TensorFlow to apply MLTSA on data.

Usage
######

Installation
##############

To use MLTSA, first install it using pip:

.. code-block:: console

    (.venv) $ pip install MLTSA
